summaryrefslogtreecommitdiffstats
path: root/kreversi/kreversi.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:55:35 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:55:35 -0600
commitc0f375feba0103bed2bac1b1f05e76e9ae28fa89 (patch)
tree9c30a9097d650343df41d867f0e008769529eb08 /kreversi/kreversi.cpp
parent0e2b76239f354a9eead0b4e37d86d390ec57ffa9 (diff)
downloadtdegames-c0f375feba0103bed2bac1b1f05e76e9ae28fa89.tar.gz
tdegames-c0f375feba0103bed2bac1b1f05e76e9ae28fa89.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kreversi/kreversi.cpp')
-rw-r--r--kreversi/kreversi.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kreversi/kreversi.cpp b/kreversi/kreversi.cpp
index 4c72251b..eee245b0 100644
--- a/kreversi/kreversi.cpp
+++ b/kreversi/kreversi.cpp
@@ -329,9 +329,9 @@ void KReversi::slotUndo()
}
if (m_game->toMove() == computerColor()) {
// Must tqrepaint so that the new move is not shown before the old
// one is removed on the screen.
- m_gameView->tqrepaint();
+ m_gameView->repaint();
computerMakeMove();
}
else
@@ -609,21 +609,21 @@ void KReversi::showGameOver(Color color)
if ( color == Nobody ) {
KNotifyClient::event(winId(), "draw", i18n("Draw!"));
TQString s = i18n("Game is drawn!\n\nYou : %1\nComputer: %2")
- .tqarg(human).tqarg(computer);
+ .arg(human).arg(computer);
KMessageBox::information(this, s, i18n("Game Ended"));
score.setType(KExtHighscore::Draw);
}
else if ( humanColor() == color ) {
KNotifyClient::event(winId(), "won", i18n("Game won!"));
TQString s = i18n("Congratulations, you have won!\n\nYou : %1\nComputer: %2")
- .tqarg(human).tqarg(computer);
+ .arg(human).arg(computer);
KMessageBox::information(this, s, i18n("Game Ended"));
score.setType(KExtHighscore::Won);
}
else {
KNotifyClient::event(winId(), "lost", i18n("Game lost!"));
TQString s = i18n("You have lost the game!\n\nYou : %1\nComputer: %2")
- .tqarg(human).tqarg(computer);
+ .arg(human).arg(computer);
KMessageBox::information(this, s, i18n("Game Ended"));
score.setType(KExtHighscore::Lost);
}
@@ -329,9 +329,9 @@ void KReversi::slotUndo()
}
if (m_game->toMove() == computerColor()) {
- // Must tqrepaint so that the new move is not shown before the old
+ // Must repaint so that the new move is not shown before the old
// one is removed on the screen.